import { inject, Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { isPresent } from 'app/core/util/operators';
import { ApplicationConfigService } from 'app/core/config/application-config.service';
import { ResilientService } from 'app/resilient/resilient-base/resilient-base.service';
import { createRequestOption } from 'app/core/request/request-util';
import { IOrganizationType, NewOrganizationType } from '../organization-type.model';

export type EntityResponseType = HttpResponse<IOrganizationType>;
export type EntityArrayResponseType = HttpResponse<IOrganizationType[]>;

@Injectable({ providedIn: 'root' })
export class OrganizationTypeService extends ResilientService<IOrganizationType, NewOrganizationType> {
  protected http = inject(HttpClient);
  protected applicationConfigService = inject(ApplicationConfigService);

  private resourceUrl = this.applicationConfigService.getEndpointFor('api/organization-types');
  getResourceUrl(): string { return this.resourceUrl; }
  
  queryByNature(nature: string): Observable<EntityArrayResponseType> {
    return this.http.get<IOrganizationType[]>(`${this.resourceUrl}/nature/${nature}`, { observe: 'response' });
  }
}
