package com.oguerreiro.resilient.domain;

import static org.assertj.core.api.Assertions.assertThat;

public class VariableCategoryAsserts {

    /**
     * Asserts that the entity has all properties (fields/relationships) set.
     *
     * @param expected the expected entity
     * @param actual the actual entity
     */
    public static void assertVariableCategoryAllPropertiesEquals(VariableCategory expected, VariableCategory actual) {
        assertVariableCategoryAutoGeneratedPropertiesEquals(expected, actual);
        assertVariableCategoryAllUpdatablePropertiesEquals(expected, actual);
    }

    /**
     * Asserts that the entity has all updatable properties (fields/relationships) set.
     *
     * @param expected the expected entity
     * @param actual the actual entity
     */
    public static void assertVariableCategoryAllUpdatablePropertiesEquals(VariableCategory expected, VariableCategory actual) {
        assertVariableCategoryUpdatableFieldsEquals(expected, actual);
        assertVariableCategoryUpdatableRelationshipsEquals(expected, actual);
    }

    /**
     * Asserts that the entity has all the auto generated properties (fields/relationships) set.
     *
     * @param expected the expected entity
     * @param actual the actual entity
     */
    public static void assertVariableCategoryAutoGeneratedPropertiesEquals(VariableCategory expected, VariableCategory actual) {
        assertThat(expected)
            .as("Verify VariableCategory auto generated properties")
            .satisfies(e -> assertThat(e.getId()).as("check id").isEqualTo(actual.getId()));
    }

    /**
     * Asserts that the entity has all the updatable fields set.
     *
     * @param expected the expected entity
     * @param actual the actual entity
     */
    public static void assertVariableCategoryUpdatableFieldsEquals(VariableCategory expected, VariableCategory actual) {
        assertThat(expected)
            .as("Verify VariableCategory relevant properties")
            .satisfies(e -> assertThat(e.getCode()).as("check code").isEqualTo(actual.getCode()))
            .satisfies(e -> assertThat(e.getName()).as("check name").isEqualTo(actual.getName()))
            .satisfies(e -> assertThat(e.getDescription()).as("check description").isEqualTo(actual.getDescription()))
            .satisfies(e -> assertThat(e.getVersion()).as("check version").isEqualTo(actual.getVersion()));
    }

    /**
     * Asserts that the entity has all the updatable relationships set.
     *
     * @param expected the expected entity
     * @param actual the actual entity
     */
    public static void assertVariableCategoryUpdatableRelationshipsEquals(VariableCategory expected, VariableCategory actual) {
        assertThat(expected)
            .as("Verify VariableCategory relationships")
            .satisfies(e -> assertThat(e.getVariableScope()).as("check variableScope").isEqualTo(actual.getVariableScope()));
    }
}
